@@ -63,12 +63,12 @@ SEXP do_mchoice_match(SEXP x, SEXP table, SEXP nomatch)
      SEXP elm_index;            /* Storage for value of first row of 
                                    first match of each element in x *\/ */
      R_len_t len;               /* Number of elements in x */
-     R_len_t t_len;             /* Number of elements in table */
+     R_len_t t_len;             /* Number of elements in table REMOVE*/
      R_len_t nfound = 0;        /* count of number of elements of
                                    x matched in table */
      char *str_ptr;             /* current location pointer */
      const char *str;
-     int i, j, k, comp, slen;
+		 int i, j, k, comp, slen;   /* REMOVE k */
 
      S_EVALUATOR
      /* get number of elements in x */
